@@ -19,8 +19,8 @@ import types
 import warnings
 from ast import AST
 
-from xonsh.inspectors import Inspector
-from xonsh.lazyasd import lazyobject
+from xonsh.lib.inspectors import Inspector
+from xonsh.lib.lazyasd import lazyobject
 from xonsh.platform import ON_POSIX
 from xonsh.tools import (
     XonshCalledProcessError,
@@ -520,16 +520,33 @@ def xonsh_builtins(execer=None):
     XSH.unload()
 
 
+class InlineImporter:
+    """Inline importer allows to import and use module attribute or function in one line."""
+
+    def __getattr__(self, name):
+        if name.startswith("__"):
+            return getattr(super(), name)
+        return __import__(name)
+
+
 class XonshSession:
     """All components defining a xonsh session."""
 
     def __init__(self):
+        """
+        Attributes
+        ----------
+        exit: int or None
+            Session attribute. In case of integer value it signals xonsh to exit
+            with returning this value as exit code.
+        """
         self.execer = None
         self.ctx = {}
         self.builtins_loaded = False
         self.history = None
         self.shell = None
         self.env = None
+        self.imp = InlineImporter()
         self.rc_files = None
 
         # AST-invoked functions
@@ -628,7 +645,7 @@ class XonshSession:
         else:
             self.env = Env({"XONSH_ENV_INHERITED": False})
 
-        self.exit = False
+        self.exit = None
         self.stdout_uncaptured = None
         self.stderr_uncaptured = None
 
